@@ -143,7 +143,8 @@ static QString replySubject(const QString &s)
     // The standandard prefix (latin for "in re", in matter of)
     const auto localPrefix = QStringLiteral("RE:");
     QStringList replyPrefixes;
-    for (const auto &prefix : getReplyPrefixes()) {
+    const auto simpleReplyPrefixes = getReplyPrefixes();
+    for (const auto &prefix : simpleReplyPrefixes) {
         replyPrefixes << prefix + QStringLiteral("\\s*:");
         replyPrefixes << prefix + QStringLiteral("\\[.+\\]:");
         replyPrefixes << prefix + QStringLiteral("\\d+:");
@@ -238,16 +239,16 @@ QString plainToHtml(const QString &body)
 // FIXME strip signature works partially for HTML mails
 static QString stripSignature(const QString &msg)
 {
-    // Following RFC 3676, only > before --
-    // I prefer to not delete a SB instead of delete good mail content.
     // We expect no CRLF from the ObjectTreeParser. The regex won't handle it.
     if (msg.contains(QStringLiteral("\r\n"))) {
         qWarning() << "Message contains CRLF, but shouldn't: " << msg;
         Q_ASSERT(false);
     }
-    const QRegExp sbDelimiterSearch(QLatin1String("(^|\n)[> ]*-- \n"));
+    // Following RFC 3676, only > before --
+    // I prefer to not delete a SB instead of delete good mail content.
+    static const QRegularExpression sbDelimiterSearch(QStringLiteral("(^|\n)[> ]*-- \n"));
     // The regular expression to look for prefix change
-    const QRegExp commonReplySearch(QLatin1String("^[ ]*>"));
+    static const QRegularExpression commonReplySearch(QStringLiteral("^[ ]*>"));
 
     QString res = msg;
     int posDeletingStart = 1; // to start looking at 0
@@ -259,7 +260,7 @@ static QString stripSignature(const QString &msg)
         int posNewLine = -1;
 
         // Look for the SB beginning
-        int posSignatureBlock = res.indexOf(QLatin1Char('-'), posDeletingStart);
+        const int posSignatureBlock = res.indexOf(QLatin1Char('-'), posDeletingStart);
         // The prefix before "-- "$
         if (res.at(posDeletingStart) == QLatin1Char('\n')) {
             ++posDeletingStart;
@@ -363,10 +364,10 @@ QString quotedPlainText(const QString &selection, const QString &fromDisplayStri
 {
     QString content = selection;
     // Remove blank lines at the beginning:
-    const int firstNonWS = content.indexOf(QRegExp(QLatin1String("\\S")));
+    const int firstNonWS = content.indexOf(QRegularExpression(QStringLiteral("\\S")));
     const int lineStart = content.lastIndexOf(QLatin1Char('\n'), firstNonWS);
     if (lineStart >= 0) {
-        content.remove(0, static_cast<unsigned int>(lineStart));
+        content.remove(0, lineStart);
     }
 
     const auto quoteString = QStringLiteral("> ");
@@ -418,10 +419,11 @@ static KMime::Types::Mailbox::List getMailingListAddresses(const KMime::Headers:
     KMime::Types::Mailbox::List mailingListAddresses;
     const QString listPost = asUnicodeString(listPostHeader);
     if (listPost.contains(QStringLiteral("mailto:"), Qt::CaseInsensitive)) {
-        QRegExp rx(QStringLiteral("<mailto:([^@>]+)@([^>]+)>"), Qt::CaseInsensitive);
-        if (rx.indexIn(listPost, 0) != -1) { // matched
+        static const QRegularExpression rx{QStringLiteral("<\\s*mailto\\s*:([^@>]+@[^>]+)>"), QRegularExpression::CaseInsensitiveOption};
+        const auto match = rx.match(listPost);
+        if (match.hasMatch()) {
             KMime::Types::Mailbox mailbox;
-            mailbox.fromUnicodeString(rx.cap(1) + QLatin1Char('@') + rx.cap(2));
+            mailbox.fromUnicodeString(match.captured(1));
             mailingListAddresses << mailbox;
         }
     }
@@ -468,8 +470,8 @@ static RecipientMailboxes getRecipients(const KMime::Types::Mailbox::List &from,
         recipients = replyToList;
 
         // strip all possible mailing list addresses from the list of Reply-To addresses
-        for (const KMime::Types::Mailbox &mailbox : mailingListAddresses) {
-            for (const KMime::Types::Mailbox &recipient : recipients) {
+        for (const KMime::Types::Mailbox &mailbox : std::as_const(mailingListAddresses)) {
+            for (const KMime::Types::Mailbox &recipient : std::as_const(recipients)) {
                 if (mailbox == recipient) {
                     recipients.removeAll(recipient);
                 }
@@ -603,8 +605,8 @@ void MailTemplates::reply(const KMime::Message::Ptr &origMsg,
     // On $datetime you wrote:
     auto dateHeader = static_cast<const KMime::Headers::Date *>(part->header(KMime::Headers::Date::staticType()));
     const QDateTime date = dateHeader ? dateHeader->dateTime() : QDateTime{};
-    const auto dateTimeString =
-        QStringLiteral("%1 %2").arg(definedLocale.toString(date.date(), QLocale::LongFormat)).arg(definedLocale.toString(date.time(), QLocale::LongFormat));
+    const QString dateTimeString =
+        definedLocale.toString(date.date(), QLocale::LongFormat) + QLatin1Char(' ') + definedLocale.toString(date.time(), QLocale::LongFormat);
     const auto onDateYouWroteLine = QStringLiteral("On %1 you wrote:\n").arg(dateTimeString);
     plainBody.append(onDateYouWroteLine);
     htmlBody.append(plainToHtml(onDateYouWroteLine));
@@ -800,15 +802,18 @@ static KMime::Types::Mailbox::List stringListToMailboxes(const QStringList &list
 static void setRecipients(KMime::Message &message, const Recipients &recipients)
 {
     message.to(true)->clear();
-    for (const auto &mb : stringListToMailboxes(recipients.to)) {
+    const auto toRecipients = stringListToMailboxes(recipients.to);
+    for (const auto &mb : toRecipients) {
         message.to()->addAddress(mb);
     }
     message.cc(true)->clear();
-    for (const auto &mb : stringListToMailboxes(recipients.cc)) {
+    const auto ccRecipients = stringListToMailboxes(recipients.cc);
+    for (const auto &mb : ccRecipients) {
         message.cc()->addAddress(mb);
     }
     message.bcc(true)->clear();
-    for (const auto &mb : stringListToMailboxes(recipients.bcc)) {
+    const auto bccRecipients = stringListToMailboxes(recipients.bcc);
+    for (const auto &mb : bccRecipients) {
         message.bcc()->addAddress(mb);
     }
 }
@@ -837,7 +842,7 @@ KMime::Message::Ptr MailTemplates::createMessage(KMime::Message::Ptr existingMes
 
     mail->date()->setDateTime(QDateTime::currentDateTime());
     mail->userAgent()->fromUnicodeString(
-        QStringLiteral("%1/%2(%3)").arg(QString::fromLocal8Bit("Kalendar")).arg(QStringLiteral("0.1")).arg(QSysInfo::prettyProductName()),
+        QStringLiteral("%1/%2(%3)").arg(QString::fromLocal8Bit("Kalendar"), QStringLiteral("0.1"), QSysInfo::prettyProductName()),
         "utf-8");
 
     setRecipients(*mail, {to, cc, bcc});
@@ -880,7 +885,7 @@ KMime::Message::Ptr MailTemplates::createMessage(KMime::Message::Ptr existingMes
             bodyPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
             bodyPart->setPreamble("This is a multi-part message in MIME format.\n");
             bodyPart->addContent(createBodyPart(body, htmlBody));
-            for (const auto &attachment : allAttachments) {
+            for (const auto &attachment : std::as_const(allAttachments)) {
                 // Just always encode attachments base64 so it's safe for binary data,
                 // except when it's another message or an ascii armored key
                 static QSet<QString> noEncodingRequired{QStringLiteral("message/rfc822"), QStringLiteral("application/pgp-keys")};
@@ -930,7 +935,7 @@ MailTemplates::createIMipMessage(const QString &from, const Recipients &recipien
 
     // Set the headers
     message->userAgent()->fromUnicodeString(
-        QStringLiteral("%1/%2(%3)").arg(QString::fromLocal8Bit("Kalendar")).arg(QStringLiteral("0.1")).arg(QSysInfo::prettyProductName()),
+        QStringLiteral("%1/%2(%3)").arg(QString::fromLocal8Bit("Kalendar"), QStringLiteral("0.1"), QSysInfo::prettyProductName()),
         "utf-8");
     message->from()->fromUnicodeString(from, "utf-8");
 
