@@ -68,8 +68,13 @@ QList<QModelIndex> HourlyIncidenceModel::sortedIncidencesFromSourceModel(const Q
             continue;
         }
 
-        if (!m_showSubTodos
-            && !srcIdx.data(IncidenceOccurrenceModel::IncidencePtr).value<KCalendarCore::Incidence::Ptr>()->relatedTo().isEmpty()) {
+        const auto incidencePtr = srcIdx.data(IncidenceOccurrenceModel::IncidencePtr).value<KCalendarCore::Incidence::Ptr>();
+        const auto incidenceIsTodo = incidencePtr->type() == Incidence::TypeTodo;
+        if (!m_showTodos && incidenceIsTodo) {
+            continue;
+        }
+
+        if (m_showTodos && incidenceIsTodo && !m_showSubTodos && !incidencePtr->relatedTo().isEmpty()) {
             continue;
         }
         // qCWarning(KALENDAR_LOG) << "found " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() <<
@@ -299,8 +304,8 @@ QVariantList HourlyIncidenceModel::layoutLines(const QDateTime &rowStart) const
 
 void HourlyIncidenceModel::resetLayoutLines()
 {
-    if(mSourceModel->calendar()->isLoading()) {
-        if(!mRefreshTimer.isActive()) {
+    if (mSourceModel->calendar()->isLoading()) {
+        if (!mRefreshTimer.isActive()) {
             mRefreshTimer.start(100);
         }
         return;
@@ -313,7 +318,7 @@ void HourlyIncidenceModel::resetLayoutLines()
     const auto numPeriods = rowCount({});
     m_laidOutLines.reserve(numPeriods);
 
-    for(int i = 0; i < numPeriods; ++i) {
+    for (int i = 0; i < numPeriods; ++i) {
         const auto periodStart = mSourceModel->start().addDays(i).startOfDay();
         const auto periodIncidenceLayout = layoutLines(periodStart);
         m_laidOutLines.append(periodIncidenceLayout);
@@ -372,7 +377,7 @@ void HourlyIncidenceModel::setModel(IncidenceOccurrenceModel *model)
 
 void HourlyIncidenceModel::slotSourceDataChanged(const QModelIndex &upperLeft, const QModelIndex &bottomRight)
 {
-    if(!upperLeft.isValid() || !bottomRight.isValid()) {
+    if (!upperLeft.isValid() || !bottomRight.isValid()) {
         return;
     }
 
@@ -401,7 +406,7 @@ void HourlyIncidenceModel::scheduleLayoutLinesUpdates(const QModelIndex &sourceI
     }
 
     for (int i = sourceFirstRow; i <= sourceLastRow; ++i) {
-        if(m_linesToUpdate.count() == m_laidOutLines.count()) {
+        if (m_linesToUpdate.count() == m_laidOutLines.count()) {
             break;
         }
 
@@ -415,7 +420,7 @@ void HourlyIncidenceModel::scheduleLayoutLinesUpdates(const QModelIndex &sourceI
         const auto firstPeriodOccurrenceAppears = startDaysFromSourceStart / mPeriodLength;
         const auto lastPeriodOccurrenceAppears = endDaysFromSourceStart / mPeriodLength;
 
-        if(firstPeriodOccurrenceAppears > m_laidOutLines.count() || lastPeriodOccurrenceAppears < 0) {
+        if (firstPeriodOccurrenceAppears > m_laidOutLines.count() || lastPeriodOccurrenceAppears < 0) {
             continue;
         }
 
@@ -436,7 +441,7 @@ void HourlyIncidenceModel::scheduleLayoutLinesUpdates(const QModelIndex &sourceI
 
 void HourlyIncidenceModel::updateScheduledLayoutLines()
 {
-    for (const auto lineIndex : m_linesToUpdate) {
+    for (const auto lineIndex : std::as_const(m_linesToUpdate)) {
         const auto periodStart = mSourceModel->start().addDays(lineIndex).startOfDay();
         const auto idx = index(lineIndex, 0);
         const auto laidOutLine = layoutLines(periodStart);
@@ -471,6 +476,23 @@ void HourlyIncidenceModel::setFilters(HourlyIncidenceModel::Filters filters)
     endResetModel();
 }
 
+bool HourlyIncidenceModel::showTodos() const
+{
+    return m_showTodos;
+}
+
+void HourlyIncidenceModel::setShowTodos(const bool showTodos)
+{
+    if (showTodos == m_showTodos) {
+        return;
+    }
+
+    m_showTodos = showTodos;
+    Q_EMIT showTodosChanged();
+
+    resetLayoutLines();
+}
+
 bool HourlyIncidenceModel::showSubTodos() const
 {
     return m_showSubTodos;
